#
# spec file for package python-epubmerge
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define upname EpubMerge
%define upnamedown epubmerge
Name:           python-epubmerge
Version:        3.2.0
Release:        1.1
Summary:        EpubMerge Calibre Plugin
License:        GPL-3.0-only
URL:            https://github.com/JimmXinu/EpubMerge
Source:         https://github.com/JimmXinu/EpubMerge/archive/v%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six
Requires(post): update-alternatives
Requires(postun): update-alternatives
# converted to update-alternatives with 2.9.0 release
Conflicts:      python2-%{upnamedown} < 2.9.0
BuildArch:      noarch
%python_subpackages

%description
This plugin provides the ability to create new EPUBs by combining the contents
of existing (non-DRM) EPUB format eBooks.

Main Features of EpubMerge Plugin:
    - Select a list of stories in calibre,
    - Order them,
    - Edit the metadata for the new combined eBook, and then,
    - Merge the contents of the EPUBs together into the new eBook, now
      including cover from metadata if set.
    - UnMerge previously merged epubs if metadata was saved during merge.
    - Configurably able to save the metadata for each merged book for UnMerging
      later if desired. (Defaults to On.)
    - Configurably able to populate custom columns from source books.
    - Options now stored inside the Library rather than an external JSON file.
    - CLI

There are a few configurable options: whether or not to insert a Table of
Contents entry for each merged book (with it's original TOC nested underneath
it), an option to flatten the TOC down to one level only, and including the
merged books comments. These options are stored by Library.

%prep
%setup -q -n %{upname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/%{upnamedown}

%post
%python_install_alternative %{upnamedown}

%postun
%python_uninstall_alternative %{upnamedown}

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/%{upnamedown}
%{python_sitelib}/%{upnamedown}
%{python_sitelib}/[Ee]pub[Mm]erge-%{version}.dist-info

%changelog
* Mon May  5 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.2.0:
  * Update Translations
  * Fix for Calibre plugin CLI
  * Don't require dc:identifier to have attribute opf:scheme=uuid when using
    IDPF font encryption
  * Add title/author/filename output on individual input epub failure
  * Decrypt encrypted/obfuscated font files
  * Save opf:file-as attr from author tags in CLI
  * Actually have 'en' default for -l in CLI.
  * Show busy cursor during unmerge
  * Consolidate FFF title/log page skipping code to fix cover issue
  * Add option to not condense TOC for a book down to a single entry if
    there's only one chapter in it.
  * Add Restore Selection option
  * Fix for writing relative paths in merged epub
- Switch to pyproject macros.
- Support both mixed case and normalized metadata directory names.
- Remove find/cp hack, package now has a proper build system.
* Fri Sep 16 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.15.0:
  * Fix remove/up/down rows when lower selected first.
  * Use Cal6 get_icons() so icon themes apply
  * Add check for multiple toc.ncx files, use last to match Calibre viewer.
  * Explicitly set --output-profile=tablet when doing epub3->epub2 autoconvert
    in BG.
  * Changes for upcoming Qt6 Calibre
  * Do merging in a BG ground.
  * Do merge in temp files instead of memory.
  * Automatically convert input epub3s to epub2s before merging.
  * Bump min Calibre version.
  * Fix FFF one-chapter story check
- Create package directory layout using find and cp so new setuptools no
  longer dies horribly.
* Tue Apr 21 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use update-alternatives for the binary
* Mon Apr 20 2020 Matej Cepl <mcepl@suse.com>
- Upgrade to 2.9.0:
  - Update translations.
  - Set allowZip64=True when writing zip files. Should only
    matter for files >2G.
  - Update cover view as well as tags and library list on new
    book create.
  - Copy six.ensure_binary for Calibre v3.
  - Reduce debug output.
  - Changes for eventual Python3 migration of Calibre.
  - Add 'current time' option to custom datetime columns.
  - Add a check and error message for unsupported epub3.
- Rewrite SPEC into the standard pythonish one.
* Tue Nov 13 2018 Matej Cepl <mcepl@suse.com>
- Initial packaging effort to collect EpubMerge 2.3.0
